@@ -9,7 +9,7 @@ from east.synonyms import synonyms
 from east import utils
 
 
-def main(args):
+def main():
     args = sys.argv[1:]
     opts, args = getopt.getopt(args, "a:l:t:sd")
     opts = dict(opts)
